@@ -147,15 +147,12 @@ class Provider(PersonProvider):
 
     prefixes = OrderedDict((('Dr.', 0.95), ('Prof. Dr.', 0.05)))
 
+    def first_name_male_abbreviated(self):
+        if hasattr(self, 'first_names_male'):
+            return self.random_element(self.first_names_male)[0] + "."
+        return self.first_name()[0]
 
-    @classmethod
-    def first_name_male_abbreviated(cls):
-        if hasattr(cls, 'first_names_male'):
-            return cls.random_element(cls.first_names_male)[0] + "."
-        return cls.first_name()[0]
-
-    @classmethod
-    def first_name_female_abbreviated(cls):
-        if hasattr(cls, 'first_names_female'):
-            return cls.random_element(cls.first_names_female)[0] + "."
-        return cls.first_name()[0]
+    def first_name_female_abbreviated(self):
+        if hasattr(self, 'first_names_female'):
+            return self.random_element(self.first_names_female)[0] + "."
+        return self.first_name()[0]
